from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.UI.Notifications
class INotificationActivationCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{53e31837-6600-4a81-9395-75cffe746f94}')
    @commethod(3)
    def Activate(self, appUserModelId: win32more.Windows.Win32.Foundation.PWSTR, invokedArgs: win32more.Windows.Win32.Foundation.PWSTR, data: POINTER(win32more.Windows.Win32.UI.Notifications.NOTIFICATION_USER_INPUT_DATA), count: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class NOTIFICATION_USER_INPUT_DATA(Structure):
    Key: win32more.Windows.Win32.Foundation.PWSTR
    Value: win32more.Windows.Win32.Foundation.PWSTR


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Management.Deployment.Preview
import win32more.Windows.Win32.System.WinRT
class ClassicAppManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Deployment.Preview.ClassicAppManager'
    @winrt_classmethod
    def FindInstalledApp(cls: win32more.Windows.Management.Deployment.Preview.IClassicAppManagerStatics, appUninstallKey: WinRT_String) -> win32more.Windows.Management.Deployment.Preview.InstalledClassicAppInfo: ...
DeploymentPreviewContract: UInt32 = 65536
class IClassicAppManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Deployment.Preview.IClassicAppManagerStatics'
    _iid_ = Guid('{e2fad668-882c-4f33-b035-0df7b90d67e6}')
    @winrt_commethod(6)
    def FindInstalledApp(self, appUninstallKey: WinRT_String) -> win32more.Windows.Management.Deployment.Preview.InstalledClassicAppInfo: ...
class IInstalledClassicAppInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Management.Deployment.Preview.IInstalledClassicAppInfo'
    _iid_ = Guid('{0a7d3da3-65d0-4086-80d6-0610d760207d}')
    @winrt_commethod(6)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DisplayVersion(self) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, None)
    DisplayVersion = property(get_DisplayVersion, None)
class InstalledClassicAppInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Management.Deployment.Preview.IInstalledClassicAppInfo
    _classid_ = 'Windows.Management.Deployment.Preview.InstalledClassicAppInfo'
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Management.Deployment.Preview.IInstalledClassicAppInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayVersion(self: win32more.Windows.Management.Deployment.Preview.IInstalledClassicAppInfo) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, None)
    DisplayVersion = property(get_DisplayVersion, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Devices.Enumeration
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Graphics.DirectX.Direct3D11
import win32more.Windows.Graphics.Imaging
import win32more.Windows.Media
import win32more.Windows.Media.Capture
import win32more.Windows.Media.Capture.Frames
import win32more.Windows.Media.Devices
import win32more.Windows.Media.Devices.Core
import win32more.Windows.Media.MediaProperties
import win32more.Windows.Perception.Spatial
import win32more.Windows.Storage.Streams
import win32more.Windows.UI.WindowManagement
import win32more.Windows.Win32.System.WinRT
class AudioMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IAudioMediaFrame
    _classid_ = 'Windows.Media.Capture.Frames.AudioMediaFrame'
    @winrt_mixinmethod
    def get_FrameReference(self: win32more.Windows.Media.Capture.Frames.IAudioMediaFrame) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_mixinmethod
    def get_AudioEncodingProperties(self: win32more.Windows.Media.Capture.Frames.IAudioMediaFrame) -> win32more.Windows.Media.MediaProperties.AudioEncodingProperties: ...
    @winrt_mixinmethod
    def GetAudioFrame(self: win32more.Windows.Media.Capture.Frames.IAudioMediaFrame) -> win32more.Windows.Media.AudioFrame: ...
    AudioEncodingProperties = property(get_AudioEncodingProperties, None)
    FrameReference = property(get_FrameReference, None)
class BufferMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IBufferMediaFrame
    _classid_ = 'Windows.Media.Capture.Frames.BufferMediaFrame'
    @winrt_mixinmethod
    def get_FrameReference(self: win32more.Windows.Media.Capture.Frames.IBufferMediaFrame) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_mixinmethod
    def get_Buffer(self: win32more.Windows.Media.Capture.Frames.IBufferMediaFrame) -> win32more.Windows.Storage.Streams.IBuffer: ...
    Buffer = property(get_Buffer, None)
    FrameReference = property(get_FrameReference, None)
class DepthMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IDepthMediaFrame
    _classid_ = 'Windows.Media.Capture.Frames.DepthMediaFrame'
    @winrt_mixinmethod
    def get_FrameReference(self: win32more.Windows.Media.Capture.Frames.IDepthMediaFrame) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_mixinmethod
    def get_VideoMediaFrame(self: win32more.Windows.Media.Capture.Frames.IDepthMediaFrame) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrame: ...
    @winrt_mixinmethod
    def get_DepthFormat(self: win32more.Windows.Media.Capture.Frames.IDepthMediaFrame) -> win32more.Windows.Media.Capture.Frames.DepthMediaFrameFormat: ...
    @winrt_mixinmethod
    def TryCreateCoordinateMapper(self: win32more.Windows.Media.Capture.Frames.IDepthMediaFrame, cameraIntrinsics: win32more.Windows.Media.Devices.Core.CameraIntrinsics, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem) -> win32more.Windows.Media.Devices.Core.DepthCorrelatedCoordinateMapper: ...
    @winrt_mixinmethod
    def get_MaxReliableDepth(self: win32more.Windows.Media.Capture.Frames.IDepthMediaFrame2) -> UInt32: ...
    @winrt_mixinmethod
    def get_MinReliableDepth(self: win32more.Windows.Media.Capture.Frames.IDepthMediaFrame2) -> UInt32: ...
    DepthFormat = property(get_DepthFormat, None)
    FrameReference = property(get_FrameReference, None)
    MaxReliableDepth = property(get_MaxReliableDepth, None)
    MinReliableDepth = property(get_MinReliableDepth, None)
    VideoMediaFrame = property(get_VideoMediaFrame, None)
class DepthMediaFrameFormat(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IDepthMediaFrameFormat
    _classid_ = 'Windows.Media.Capture.Frames.DepthMediaFrameFormat'
    @winrt_mixinmethod
    def get_VideoFormat(self: win32more.Windows.Media.Capture.Frames.IDepthMediaFrameFormat) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrameFormat: ...
    @winrt_mixinmethod
    def get_DepthScaleInMeters(self: win32more.Windows.Media.Capture.Frames.IDepthMediaFrameFormat) -> Double: ...
    DepthScaleInMeters = property(get_DepthScaleInMeters, None)
    VideoFormat = property(get_VideoFormat, None)
class IAudioMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IAudioMediaFrame'
    _iid_ = Guid('{a3a9feff-8021-441b-9a46-e7f0137b7981}')
    @winrt_commethod(6)
    def get_FrameReference(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_commethod(7)
    def get_AudioEncodingProperties(self) -> win32more.Windows.Media.MediaProperties.AudioEncodingProperties: ...
    @winrt_commethod(8)
    def GetAudioFrame(self) -> win32more.Windows.Media.AudioFrame: ...
    AudioEncodingProperties = property(get_AudioEncodingProperties, None)
    FrameReference = property(get_FrameReference, None)
class IBufferMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IBufferMediaFrame'
    _iid_ = Guid('{b5b153c7-9b84-4062-b79c-a365b2596854}')
    @winrt_commethod(6)
    def get_FrameReference(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_commethod(7)
    def get_Buffer(self) -> win32more.Windows.Storage.Streams.IBuffer: ...
    Buffer = property(get_Buffer, None)
    FrameReference = property(get_FrameReference, None)
class IDepthMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IDepthMediaFrame'
    _iid_ = Guid('{47135e4f-8549-45c0-925b-80d35efdb10a}')
    @winrt_commethod(6)
    def get_FrameReference(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_commethod(7)
    def get_VideoMediaFrame(self) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrame: ...
    @winrt_commethod(8)
    def get_DepthFormat(self) -> win32more.Windows.Media.Capture.Frames.DepthMediaFrameFormat: ...
    @winrt_commethod(9)
    def TryCreateCoordinateMapper(self, cameraIntrinsics: win32more.Windows.Media.Devices.Core.CameraIntrinsics, coordinateSystem: win32more.Windows.Perception.Spatial.SpatialCoordinateSystem) -> win32more.Windows.Media.Devices.Core.DepthCorrelatedCoordinateMapper: ...
    DepthFormat = property(get_DepthFormat, None)
    FrameReference = property(get_FrameReference, None)
    VideoMediaFrame = property(get_VideoMediaFrame, None)
class IDepthMediaFrame2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IDepthMediaFrame2'
    _iid_ = Guid('{6cca473d-c4a4-4176-b0cd-33eae3b35aa3}')
    @winrt_commethod(6)
    def get_MaxReliableDepth(self) -> UInt32: ...
    @winrt_commethod(7)
    def get_MinReliableDepth(self) -> UInt32: ...
    MaxReliableDepth = property(get_MaxReliableDepth, None)
    MinReliableDepth = property(get_MinReliableDepth, None)
class IDepthMediaFrameFormat(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IDepthMediaFrameFormat'
    _iid_ = Guid('{c312cf40-d729-453e-8780-2e04f140d28e}')
    @winrt_commethod(6)
    def get_VideoFormat(self) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrameFormat: ...
    @winrt_commethod(7)
    def get_DepthScaleInMeters(self) -> Double: ...
    DepthScaleInMeters = property(get_DepthScaleInMeters, None)
    VideoFormat = property(get_VideoFormat, None)
class IInfraredMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IInfraredMediaFrame'
    _iid_ = Guid('{3fd13503-004b-4f0e-91ac-465299b41658}')
    @winrt_commethod(6)
    def get_FrameReference(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_commethod(7)
    def get_VideoMediaFrame(self) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrame: ...
    @winrt_commethod(8)
    def get_IsIlluminated(self) -> Boolean: ...
    FrameReference = property(get_FrameReference, None)
    IsIlluminated = property(get_IsIlluminated, None)
    VideoMediaFrame = property(get_VideoMediaFrame, None)
class IMediaFrameArrivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameArrivedEventArgs'
    _iid_ = Guid('{0b430add-a490-4435-ada1-9affd55239f7}')
class IMediaFrameFormat(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameFormat'
    _iid_ = Guid('{71902b4e-b279-4a97-a9db-bd5a2fb78f39}')
    @winrt_commethod(6)
    def get_MajorType(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_Subtype(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_FrameRate(self) -> win32more.Windows.Media.MediaProperties.MediaRatio: ...
    @winrt_commethod(9)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[Guid, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(10)
    def get_VideoFormat(self) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrameFormat: ...
    FrameRate = property(get_FrameRate, None)
    MajorType = property(get_MajorType, None)
    Properties = property(get_Properties, None)
    Subtype = property(get_Subtype, None)
    VideoFormat = property(get_VideoFormat, None)
class IMediaFrameFormat2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameFormat2'
    _iid_ = Guid('{63856340-5e87-4c10-86d1-6df097a6c6a8}')
    @winrt_commethod(6)
    def get_AudioEncodingProperties(self) -> win32more.Windows.Media.MediaProperties.AudioEncodingProperties: ...
    AudioEncodingProperties = property(get_AudioEncodingProperties, None)
class IMediaFrameReader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameReader'
    _iid_ = Guid('{e4c94395-2028-48ed-90b0-d1c1b162e24c}')
    @winrt_commethod(6)
    def add_FrameArrived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Frames.MediaFrameReader, win32more.Windows.Media.Capture.Frames.MediaFrameArrivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_FrameArrived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def TryAcquireLatestFrame(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_commethod(9)
    def StartAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameReaderStartStatus]: ...
    @winrt_commethod(10)
    def StopAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    FrameArrived = event()
class IMediaFrameReader2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameReader2'
    _iid_ = Guid('{871127b3-8531-4050-87cc-a13733cf3e9b}')
    @winrt_commethod(6)
    def put_AcquisitionMode(self, value: win32more.Windows.Media.Capture.Frames.MediaFrameReaderAcquisitionMode) -> Void: ...
    @winrt_commethod(7)
    def get_AcquisitionMode(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameReaderAcquisitionMode: ...
    AcquisitionMode = property(get_AcquisitionMode, put_AcquisitionMode)
class IMediaFrameReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameReference'
    _iid_ = Guid('{f6b88641-f0dc-4044-8dc9-961cedd05bad}')
    @winrt_commethod(6)
    def get_SourceKind(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceKind: ...
    @winrt_commethod(7)
    def get_Format(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameFormat: ...
    @winrt_commethod(8)
    def get_SystemRelativeTime(self) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_commethod(9)
    def get_Duration(self) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_commethod(10)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[Guid, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(11)
    def get_BufferMediaFrame(self) -> win32more.Windows.Media.Capture.Frames.BufferMediaFrame: ...
    @winrt_commethod(12)
    def get_VideoMediaFrame(self) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrame: ...
    @winrt_commethod(13)
    def get_CoordinateSystem(self) -> win32more.Windows.Perception.Spatial.SpatialCoordinateSystem: ...
    BufferMediaFrame = property(get_BufferMediaFrame, None)
    CoordinateSystem = property(get_CoordinateSystem, None)
    Duration = property(get_Duration, None)
    Format = property(get_Format, None)
    Properties = property(get_Properties, None)
    SourceKind = property(get_SourceKind, None)
    SystemRelativeTime = property(get_SystemRelativeTime, None)
    VideoMediaFrame = property(get_VideoMediaFrame, None)
class IMediaFrameReference2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameReference2'
    _iid_ = Guid('{ddbc3ecc-d5b2-49ef-836a-947d989b80c1}')
    @winrt_commethod(6)
    def get_AudioMediaFrame(self) -> win32more.Windows.Media.Capture.Frames.AudioMediaFrame: ...
    AudioMediaFrame = property(get_AudioMediaFrame, None)
class IMediaFrameSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSource'
    _iid_ = Guid('{d6782953-90db-46a8-8add-2aa884a8d253}')
    @winrt_commethod(6)
    def get_Info(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceInfo: ...
    @winrt_commethod(7)
    def get_Controller(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceController: ...
    @winrt_commethod(8)
    def get_SupportedFormats(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Capture.Frames.MediaFrameFormat]: ...
    @winrt_commethod(9)
    def get_CurrentFormat(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameFormat: ...
    @winrt_commethod(10)
    def SetFormatAsync(self, format: win32more.Windows.Media.Capture.Frames.MediaFrameFormat) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(11)
    def add_FormatChanged(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Frames.MediaFrameSource, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(12)
    def remove_FormatChanged(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(13)
    def TryGetCameraIntrinsics(self, format: win32more.Windows.Media.Capture.Frames.MediaFrameFormat) -> win32more.Windows.Media.Devices.Core.CameraIntrinsics: ...
    Controller = property(get_Controller, None)
    CurrentFormat = property(get_CurrentFormat, None)
    Info = property(get_Info, None)
    SupportedFormats = property(get_SupportedFormats, None)
    FormatChanged = event()
class IMediaFrameSourceController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceController'
    _iid_ = Guid('{6d076635-316d-4b8f-b7b6-eeb04a8c6525}')
    @winrt_commethod(6)
    def GetPropertyAsync(self, propertyId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceGetPropertyResult]: ...
    @winrt_commethod(7)
    def SetPropertyAsync(self, propertyId: WinRT_String, propertyValue: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceSetPropertyStatus]: ...
    @winrt_commethod(8)
    def get_VideoDeviceController(self) -> win32more.Windows.Media.Devices.VideoDeviceController: ...
    VideoDeviceController = property(get_VideoDeviceController, None)
class IMediaFrameSourceController2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceController2'
    _iid_ = Guid('{efc49fd4-fcf2-4a03-b4e4-ac9628739bee}')
    @winrt_commethod(6)
    def GetPropertyByExtendedIdAsync(self, extendedPropertyId: PassArray[Byte], maxPropertyValueSize: win32more.Windows.Foundation.IReference[UInt32]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceGetPropertyResult]: ...
    @winrt_commethod(7)
    def SetPropertyByExtendedIdAsync(self, extendedPropertyId: PassArray[Byte], propertyValue: PassArray[Byte]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceSetPropertyStatus]: ...
class IMediaFrameSourceController3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceController3'
    _iid_ = Guid('{1f0cf815-2464-4651-b1e8-4a82dbdb54de}')
    @winrt_commethod(6)
    def get_AudioDeviceController(self) -> win32more.Windows.Media.Devices.AudioDeviceController: ...
    AudioDeviceController = property(get_AudioDeviceController, None)
class IMediaFrameSourceGetPropertyResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceGetPropertyResult'
    _iid_ = Guid('{088616c2-3a64-4bd5-bd2b-e7c898d2f37a}')
    @winrt_commethod(6)
    def get_Status(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceGetPropertyStatus: ...
    @winrt_commethod(7)
    def get_Value(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class IMediaFrameSourceGroup(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceGroup'
    _iid_ = Guid('{7f605b87-4832-4b5f-ae3d-412faab37d34}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_DisplayName(self) -> WinRT_String: ...
    @winrt_commethod(8)
    def get_SourceInfos(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Capture.Frames.MediaFrameSourceInfo]: ...
    DisplayName = property(get_DisplayName, None)
    Id = property(get_Id, None)
    SourceInfos = property(get_SourceInfos, None)
class IMediaFrameSourceGroupStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceGroupStatics'
    _iid_ = Guid('{1c48bfc5-436f-4508-94cf-d5d8b7326445}')
    @winrt_commethod(6)
    def FindAllAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Capture.Frames.MediaFrameSourceGroup]]: ...
    @winrt_commethod(7)
    def FromIdAsync(self, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceGroup]: ...
    @winrt_commethod(8)
    def GetDeviceSelector(self) -> WinRT_String: ...
class IMediaFrameSourceInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceInfo'
    _iid_ = Guid('{87bdc9cd-4601-408f-91cf-038318cd0af3}')
    @winrt_commethod(6)
    def get_Id(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_MediaStreamType(self) -> win32more.Windows.Media.Capture.MediaStreamType: ...
    @winrt_commethod(8)
    def get_SourceKind(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceKind: ...
    @winrt_commethod(9)
    def get_SourceGroup(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceGroup: ...
    @winrt_commethod(10)
    def get_DeviceInformation(self) -> win32more.Windows.Devices.Enumeration.DeviceInformation: ...
    @winrt_commethod(11)
    def get_Properties(self) -> win32more.Windows.Foundation.Collections.IMapView[Guid, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_commethod(12)
    def get_CoordinateSystem(self) -> win32more.Windows.Perception.Spatial.SpatialCoordinateSystem: ...
    CoordinateSystem = property(get_CoordinateSystem, None)
    DeviceInformation = property(get_DeviceInformation, None)
    Id = property(get_Id, None)
    MediaStreamType = property(get_MediaStreamType, None)
    Properties = property(get_Properties, None)
    SourceGroup = property(get_SourceGroup, None)
    SourceKind = property(get_SourceKind, None)
class IMediaFrameSourceInfo2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceInfo2'
    _iid_ = Guid('{195a7855-6457-42c6-a769-19b65bd32e6e}')
    @winrt_commethod(6)
    def get_ProfileId(self) -> WinRT_String: ...
    @winrt_commethod(7)
    def get_VideoProfileMediaDescription(self) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Capture.MediaCaptureVideoProfileMediaDescription]: ...
    ProfileId = property(get_ProfileId, None)
    VideoProfileMediaDescription = property(get_VideoProfileMediaDescription, None)
class IMediaFrameSourceInfo3(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceInfo3'
    _iid_ = Guid('{ca824ab6-66ea-5885-a2b6-26c0eeec3c7b}')
    @winrt_commethod(6)
    def GetRelativePanel(self, displayRegion: win32more.Windows.UI.WindowManagement.DisplayRegion) -> win32more.Windows.Devices.Enumeration.Panel: ...
class IMediaFrameSourceInfo4(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMediaFrameSourceInfo4'
    _iid_ = Guid('{4817d721-85eb-470c-8f37-43ca5498e41d}')
    @winrt_commethod(6)
    def get_IsShareable(self) -> Boolean: ...
    IsShareable = property(get_IsShareable, None)
class IMultiSourceMediaFrameArrivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMultiSourceMediaFrameArrivedEventArgs'
    _iid_ = Guid('{63115e01-cf51-48fd-aab0-6d693eb48127}')
class IMultiSourceMediaFrameReader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader'
    _iid_ = Guid('{8d144402-f763-488d-98f2-b437bcf075e7}')
    @winrt_commethod(6)
    def add_FrameArrived(self, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Frames.MultiSourceMediaFrameReader, win32more.Windows.Media.Capture.Frames.MultiSourceMediaFrameArrivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(7)
    def remove_FrameArrived(self, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(8)
    def TryAcquireLatestFrame(self) -> win32more.Windows.Media.Capture.Frames.MultiSourceMediaFrameReference: ...
    @winrt_commethod(9)
    def StartAsync(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MultiSourceMediaFrameReaderStartStatus]: ...
    @winrt_commethod(10)
    def StopAsync(self) -> win32more.Windows.Foundation.IAsyncAction: ...
    FrameArrived = event()
class IMultiSourceMediaFrameReader2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader2'
    _iid_ = Guid('{ef5c8abd-fc5c-4c6b-9d81-3cb9cc637c26}')
    @winrt_commethod(6)
    def put_AcquisitionMode(self, value: win32more.Windows.Media.Capture.Frames.MediaFrameReaderAcquisitionMode) -> Void: ...
    @winrt_commethod(7)
    def get_AcquisitionMode(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameReaderAcquisitionMode: ...
    AcquisitionMode = property(get_AcquisitionMode, put_AcquisitionMode)
class IMultiSourceMediaFrameReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    _classid_ = 'Windows.Media.Capture.Frames.IMultiSourceMediaFrameReference'
    _iid_ = Guid('{21964b1a-7fe2-44d6-92e5-298e6d2810e9}')
    @winrt_commethod(6)
    def TryGetFrameReferenceBySourceId(self, sourceId: WinRT_String) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
class IVideoMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IVideoMediaFrame'
    _iid_ = Guid('{00dd4ccb-32bd-4fe1-a013-7cc13cf5dbcf}')
    @winrt_commethod(6)
    def get_FrameReference(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_commethod(7)
    def get_VideoFormat(self) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrameFormat: ...
    @winrt_commethod(8)
    def get_SoftwareBitmap(self) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_commethod(9)
    def get_Direct3DSurface(self) -> win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DSurface: ...
    @winrt_commethod(10)
    def get_CameraIntrinsics(self) -> win32more.Windows.Media.Devices.Core.CameraIntrinsics: ...
    @winrt_commethod(11)
    def get_InfraredMediaFrame(self) -> win32more.Windows.Media.Capture.Frames.InfraredMediaFrame: ...
    @winrt_commethod(12)
    def get_DepthMediaFrame(self) -> win32more.Windows.Media.Capture.Frames.DepthMediaFrame: ...
    @winrt_commethod(13)
    def GetVideoFrame(self) -> win32more.Windows.Media.VideoFrame: ...
    CameraIntrinsics = property(get_CameraIntrinsics, None)
    DepthMediaFrame = property(get_DepthMediaFrame, None)
    Direct3DSurface = property(get_Direct3DSurface, None)
    FrameReference = property(get_FrameReference, None)
    InfraredMediaFrame = property(get_InfraredMediaFrame, None)
    SoftwareBitmap = property(get_SoftwareBitmap, None)
    VideoFormat = property(get_VideoFormat, None)
class IVideoMediaFrameFormat(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Media.Capture.Frames.IVideoMediaFrameFormat'
    _iid_ = Guid('{46027fc0-d71b-45c7-8f14-6d9a0ae604e4}')
    @winrt_commethod(6)
    def get_MediaFrameFormat(self) -> win32more.Windows.Media.Capture.Frames.MediaFrameFormat: ...
    @winrt_commethod(7)
    def get_DepthFormat(self) -> win32more.Windows.Media.Capture.Frames.DepthMediaFrameFormat: ...
    @winrt_commethod(8)
    def get_Width(self) -> UInt32: ...
    @winrt_commethod(9)
    def get_Height(self) -> UInt32: ...
    DepthFormat = property(get_DepthFormat, None)
    Height = property(get_Height, None)
    MediaFrameFormat = property(get_MediaFrameFormat, None)
    Width = property(get_Width, None)
class InfraredMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IInfraredMediaFrame
    _classid_ = 'Windows.Media.Capture.Frames.InfraredMediaFrame'
    @winrt_mixinmethod
    def get_FrameReference(self: win32more.Windows.Media.Capture.Frames.IInfraredMediaFrame) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_mixinmethod
    def get_VideoMediaFrame(self: win32more.Windows.Media.Capture.Frames.IInfraredMediaFrame) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrame: ...
    @winrt_mixinmethod
    def get_IsIlluminated(self: win32more.Windows.Media.Capture.Frames.IInfraredMediaFrame) -> Boolean: ...
    FrameReference = property(get_FrameReference, None)
    IsIlluminated = property(get_IsIlluminated, None)
    VideoMediaFrame = property(get_VideoMediaFrame, None)
class MediaFrameArrivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameArrivedEventArgs
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameArrivedEventArgs'
class MediaFrameFormat(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameFormat
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameFormat'
    @winrt_mixinmethod
    def get_MajorType(self: win32more.Windows.Media.Capture.Frames.IMediaFrameFormat) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Subtype(self: win32more.Windows.Media.Capture.Frames.IMediaFrameFormat) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FrameRate(self: win32more.Windows.Media.Capture.Frames.IMediaFrameFormat) -> win32more.Windows.Media.MediaProperties.MediaRatio: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Media.Capture.Frames.IMediaFrameFormat) -> win32more.Windows.Foundation.Collections.IMapView[Guid, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_VideoFormat(self: win32more.Windows.Media.Capture.Frames.IMediaFrameFormat) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrameFormat: ...
    @winrt_mixinmethod
    def get_AudioEncodingProperties(self: win32more.Windows.Media.Capture.Frames.IMediaFrameFormat2) -> win32more.Windows.Media.MediaProperties.AudioEncodingProperties: ...
    AudioEncodingProperties = property(get_AudioEncodingProperties, None)
    FrameRate = property(get_FrameRate, None)
    MajorType = property(get_MajorType, None)
    Properties = property(get_Properties, None)
    Subtype = property(get_Subtype, None)
    VideoFormat = property(get_VideoFormat, None)
class MediaFrameReader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameReader
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameReader'
    @winrt_mixinmethod
    def add_FrameArrived(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReader, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Frames.MediaFrameReader, win32more.Windows.Media.Capture.Frames.MediaFrameArrivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameArrived(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReader, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def TryAcquireLatestFrame(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReader) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_mixinmethod
    def StartAsync(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReader) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameReaderStartStatus]: ...
    @winrt_mixinmethod
    def StopAsync(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReader) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def put_AcquisitionMode(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReader2, value: win32more.Windows.Media.Capture.Frames.MediaFrameReaderAcquisitionMode) -> Void: ...
    @winrt_mixinmethod
    def get_AcquisitionMode(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReader2) -> win32more.Windows.Media.Capture.Frames.MediaFrameReaderAcquisitionMode: ...
    AcquisitionMode = property(get_AcquisitionMode, put_AcquisitionMode)
    FrameArrived = event()
class MediaFrameReaderAcquisitionMode(Enum, Int32):
    Realtime = 0
    Buffered = 1
class MediaFrameReaderStartStatus(Enum, Int32):
    Success = 0
    UnknownFailure = 1
    DeviceNotAvailable = 2
    OutputFormatNotSupported = 3
    ExclusiveControlNotAvailable = 4
class MediaFrameReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameReference
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameReference'
    @winrt_mixinmethod
    def get_SourceKind(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceKind: ...
    @winrt_mixinmethod
    def get_Format(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference) -> win32more.Windows.Media.Capture.Frames.MediaFrameFormat: ...
    @winrt_mixinmethod
    def get_SystemRelativeTime(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference) -> win32more.Windows.Foundation.IReference[win32more.Windows.Foundation.TimeSpan]: ...
    @winrt_mixinmethod
    def get_Duration(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference) -> win32more.Windows.Foundation.TimeSpan: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference) -> win32more.Windows.Foundation.Collections.IMapView[Guid, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_BufferMediaFrame(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference) -> win32more.Windows.Media.Capture.Frames.BufferMediaFrame: ...
    @winrt_mixinmethod
    def get_VideoMediaFrame(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrame: ...
    @winrt_mixinmethod
    def get_CoordinateSystem(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference) -> win32more.Windows.Perception.Spatial.SpatialCoordinateSystem: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def get_AudioMediaFrame(self: win32more.Windows.Media.Capture.Frames.IMediaFrameReference2) -> win32more.Windows.Media.Capture.Frames.AudioMediaFrame: ...
    AudioMediaFrame = property(get_AudioMediaFrame, None)
    BufferMediaFrame = property(get_BufferMediaFrame, None)
    CoordinateSystem = property(get_CoordinateSystem, None)
    Duration = property(get_Duration, None)
    Format = property(get_Format, None)
    Properties = property(get_Properties, None)
    SourceKind = property(get_SourceKind, None)
    SystemRelativeTime = property(get_SystemRelativeTime, None)
    VideoMediaFrame = property(get_VideoMediaFrame, None)
class MediaFrameSource(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameSource
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameSource'
    @winrt_mixinmethod
    def get_Info(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSource) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceInfo: ...
    @winrt_mixinmethod
    def get_Controller(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSource) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceController: ...
    @winrt_mixinmethod
    def get_SupportedFormats(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSource) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Capture.Frames.MediaFrameFormat]: ...
    @winrt_mixinmethod
    def get_CurrentFormat(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSource) -> win32more.Windows.Media.Capture.Frames.MediaFrameFormat: ...
    @winrt_mixinmethod
    def SetFormatAsync(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSource, format: win32more.Windows.Media.Capture.Frames.MediaFrameFormat) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def add_FormatChanged(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSource, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Frames.MediaFrameSource, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FormatChanged(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSource, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def TryGetCameraIntrinsics(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSource, format: win32more.Windows.Media.Capture.Frames.MediaFrameFormat) -> win32more.Windows.Media.Devices.Core.CameraIntrinsics: ...
    Controller = property(get_Controller, None)
    CurrentFormat = property(get_CurrentFormat, None)
    Info = property(get_Info, None)
    SupportedFormats = property(get_SupportedFormats, None)
    FormatChanged = event()
class MediaFrameSourceController(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceController
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameSourceController'
    @winrt_mixinmethod
    def GetPropertyAsync(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceController, propertyId: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceGetPropertyResult]: ...
    @winrt_mixinmethod
    def SetPropertyAsync(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceController, propertyId: WinRT_String, propertyValue: win32more.Windows.Win32.System.WinRT.IInspectable) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceSetPropertyStatus]: ...
    @winrt_mixinmethod
    def get_VideoDeviceController(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceController) -> win32more.Windows.Media.Devices.VideoDeviceController: ...
    @winrt_mixinmethod
    def GetPropertyByExtendedIdAsync(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceController2, extendedPropertyId: PassArray[Byte], maxPropertyValueSize: win32more.Windows.Foundation.IReference[UInt32]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceGetPropertyResult]: ...
    @winrt_mixinmethod
    def SetPropertyByExtendedIdAsync(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceController2, extendedPropertyId: PassArray[Byte], propertyValue: PassArray[Byte]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceSetPropertyStatus]: ...
    @winrt_mixinmethod
    def get_AudioDeviceController(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceController3) -> win32more.Windows.Media.Devices.AudioDeviceController: ...
    AudioDeviceController = property(get_AudioDeviceController, None)
    VideoDeviceController = property(get_VideoDeviceController, None)
class MediaFrameSourceGetPropertyResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGetPropertyResult
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameSourceGetPropertyResult'
    @winrt_mixinmethod
    def get_Status(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGetPropertyResult) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceGetPropertyStatus: ...
    @winrt_mixinmethod
    def get_Value(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGetPropertyResult) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    Status = property(get_Status, None)
    Value = property(get_Value, None)
class MediaFrameSourceGetPropertyStatus(Enum, Int32):
    Success = 0
    UnknownFailure = 1
    NotSupported = 2
    DeviceNotAvailable = 3
    MaxPropertyValueSizeTooSmall = 4
    MaxPropertyValueSizeRequired = 5
class MediaFrameSourceGroup(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGroup
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameSourceGroup'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGroup) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGroup) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_SourceInfos(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGroup) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Capture.Frames.MediaFrameSourceInfo]: ...
    @winrt_classmethod
    def FindAllAsync(cls: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGroupStatics) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Capture.Frames.MediaFrameSourceGroup]]: ...
    @winrt_classmethod
    def FromIdAsync(cls: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGroupStatics, id: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MediaFrameSourceGroup]: ...
    @winrt_classmethod
    def GetDeviceSelector(cls: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceGroupStatics) -> WinRT_String: ...
    DisplayName = property(get_DisplayName, None)
    Id = property(get_Id, None)
    SourceInfos = property(get_SourceInfos, None)
class MediaFrameSourceInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo
    _classid_ = 'Windows.Media.Capture.Frames.MediaFrameSourceInfo'
    @winrt_mixinmethod
    def get_Id(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_MediaStreamType(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo) -> win32more.Windows.Media.Capture.MediaStreamType: ...
    @winrt_mixinmethod
    def get_SourceKind(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceKind: ...
    @winrt_mixinmethod
    def get_SourceGroup(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo) -> win32more.Windows.Media.Capture.Frames.MediaFrameSourceGroup: ...
    @winrt_mixinmethod
    def get_DeviceInformation(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo) -> win32more.Windows.Devices.Enumeration.DeviceInformation: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo) -> win32more.Windows.Foundation.Collections.IMapView[Guid, win32more.Windows.Win32.System.WinRT.IInspectable]: ...
    @winrt_mixinmethod
    def get_CoordinateSystem(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo) -> win32more.Windows.Perception.Spatial.SpatialCoordinateSystem: ...
    @winrt_mixinmethod
    def get_ProfileId(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo2) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_VideoProfileMediaDescription(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo2) -> win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Media.Capture.MediaCaptureVideoProfileMediaDescription]: ...
    @winrt_mixinmethod
    def GetRelativePanel(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo3, displayRegion: win32more.Windows.UI.WindowManagement.DisplayRegion) -> win32more.Windows.Devices.Enumeration.Panel: ...
    @winrt_mixinmethod
    def get_IsShareable(self: win32more.Windows.Media.Capture.Frames.IMediaFrameSourceInfo4) -> Boolean: ...
    CoordinateSystem = property(get_CoordinateSystem, None)
    DeviceInformation = property(get_DeviceInformation, None)
    Id = property(get_Id, None)
    IsShareable = property(get_IsShareable, None)
    MediaStreamType = property(get_MediaStreamType, None)
    ProfileId = property(get_ProfileId, None)
    Properties = property(get_Properties, None)
    SourceGroup = property(get_SourceGroup, None)
    SourceKind = property(get_SourceKind, None)
    VideoProfileMediaDescription = property(get_VideoProfileMediaDescription, None)
class MediaFrameSourceKind(Enum, Int32):
    Custom = 0
    Color = 1
    Infrared = 2
    Depth = 3
    Audio = 4
    Image = 5
    Metadata = 6
class MediaFrameSourceSetPropertyStatus(Enum, Int32):
    Success = 0
    UnknownFailure = 1
    NotSupported = 2
    InvalidValue = 3
    DeviceNotAvailable = 4
    NotInControl = 5
class MultiSourceMediaFrameArrivedEventArgs(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameArrivedEventArgs
    _classid_ = 'Windows.Media.Capture.Frames.MultiSourceMediaFrameArrivedEventArgs'
class MultiSourceMediaFrameReader(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader
    _classid_ = 'Windows.Media.Capture.Frames.MultiSourceMediaFrameReader'
    @winrt_mixinmethod
    def add_FrameArrived(self: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader, handler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Media.Capture.Frames.MultiSourceMediaFrameReader, win32more.Windows.Media.Capture.Frames.MultiSourceMediaFrameArrivedEventArgs]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_FrameArrived(self: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader, token: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def TryAcquireLatestFrame(self: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader) -> win32more.Windows.Media.Capture.Frames.MultiSourceMediaFrameReference: ...
    @winrt_mixinmethod
    def StartAsync(self: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Media.Capture.Frames.MultiSourceMediaFrameReaderStartStatus]: ...
    @winrt_mixinmethod
    def StopAsync(self: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
    @winrt_mixinmethod
    def put_AcquisitionMode(self: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader2, value: win32more.Windows.Media.Capture.Frames.MediaFrameReaderAcquisitionMode) -> Void: ...
    @winrt_mixinmethod
    def get_AcquisitionMode(self: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReader2) -> win32more.Windows.Media.Capture.Frames.MediaFrameReaderAcquisitionMode: ...
    AcquisitionMode = property(get_AcquisitionMode, put_AcquisitionMode)
    FrameArrived = event()
class MultiSourceMediaFrameReaderStartStatus(Enum, Int32):
    Success = 0
    NotSupported = 1
    InsufficientResources = 2
    DeviceNotAvailable = 3
    UnknownFailure = 4
class MultiSourceMediaFrameReference(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    implements: Tuple[ContextManagerProtocol]
    default_interface: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReference
    _classid_ = 'Windows.Media.Capture.Frames.MultiSourceMediaFrameReference'
    @winrt_mixinmethod
    def TryGetFrameReferenceBySourceId(self: win32more.Windows.Media.Capture.Frames.IMultiSourceMediaFrameReference, sourceId: WinRT_String) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_mixinmethod
    def Close(self: win32more.Windows.Foundation.IClosable) -> Void: ...
class VideoMediaFrame(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame
    _classid_ = 'Windows.Media.Capture.Frames.VideoMediaFrame'
    @winrt_mixinmethod
    def get_FrameReference(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame) -> win32more.Windows.Media.Capture.Frames.MediaFrameReference: ...
    @winrt_mixinmethod
    def get_VideoFormat(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame) -> win32more.Windows.Media.Capture.Frames.VideoMediaFrameFormat: ...
    @winrt_mixinmethod
    def get_SoftwareBitmap(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame) -> win32more.Windows.Graphics.Imaging.SoftwareBitmap: ...
    @winrt_mixinmethod
    def get_Direct3DSurface(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame) -> win32more.Windows.Graphics.DirectX.Direct3D11.IDirect3DSurface: ...
    @winrt_mixinmethod
    def get_CameraIntrinsics(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame) -> win32more.Windows.Media.Devices.Core.CameraIntrinsics: ...
    @winrt_mixinmethod
    def get_InfraredMediaFrame(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame) -> win32more.Windows.Media.Capture.Frames.InfraredMediaFrame: ...
    @winrt_mixinmethod
    def get_DepthMediaFrame(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame) -> win32more.Windows.Media.Capture.Frames.DepthMediaFrame: ...
    @winrt_mixinmethod
    def GetVideoFrame(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrame) -> win32more.Windows.Media.VideoFrame: ...
    CameraIntrinsics = property(get_CameraIntrinsics, None)
    DepthMediaFrame = property(get_DepthMediaFrame, None)
    Direct3DSurface = property(get_Direct3DSurface, None)
    FrameReference = property(get_FrameReference, None)
    InfraredMediaFrame = property(get_InfraredMediaFrame, None)
    SoftwareBitmap = property(get_SoftwareBitmap, None)
    VideoFormat = property(get_VideoFormat, None)
class VideoMediaFrameFormat(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Media.Capture.Frames.IVideoMediaFrameFormat
    _classid_ = 'Windows.Media.Capture.Frames.VideoMediaFrameFormat'
    @winrt_mixinmethod
    def get_MediaFrameFormat(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrameFormat) -> win32more.Windows.Media.Capture.Frames.MediaFrameFormat: ...
    @winrt_mixinmethod
    def get_DepthFormat(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrameFormat) -> win32more.Windows.Media.Capture.Frames.DepthMediaFrameFormat: ...
    @winrt_mixinmethod
    def get_Width(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrameFormat) -> UInt32: ...
    @winrt_mixinmethod
    def get_Height(self: win32more.Windows.Media.Capture.Frames.IVideoMediaFrameFormat) -> UInt32: ...
    DepthFormat = property(get_DepthFormat, None)
    Height = property(get_Height, None)
    MediaFrameFormat = property(get_MediaFrameFormat, None)
    Width = property(get_Width, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage
import win32more.Windows.Storage.BulkAccess
import win32more.Windows.Storage.FileProperties
import win32more.Windows.Storage.Search
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class FileInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.BulkAccess.IStorageItemInformation
    _classid_ = 'Windows.Storage.BulkAccess.FileInformation'
    @winrt_mixinmethod
    def get_MusicProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.MusicProperties: ...
    @winrt_mixinmethod
    def get_VideoProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.VideoProperties: ...
    @winrt_mixinmethod
    def get_ImageProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.ImageProperties: ...
    @winrt_mixinmethod
    def get_DocumentProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.DocumentProperties: ...
    @winrt_mixinmethod
    def get_BasicProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.BasicProperties: ...
    @winrt_mixinmethod
    def get_Thumbnail(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.StorageItemThumbnail: ...
    @winrt_mixinmethod
    def add_ThumbnailUpdated(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation, changedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.BulkAccess.IStorageItemInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ThumbnailUpdated(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PropertiesUpdated(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation, changedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.BulkAccess.IStorageItemInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PropertiesUpdated(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def get_FileType(self: win32more.Windows.Storage.IStorageFile) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_ContentType(self: win32more.Windows.Storage.IStorageFile) -> WinRT_String: ...
    @winrt_mixinmethod
    def OpenAsync(self: win32more.Windows.Storage.IStorageFile, accessMode: win32more.Windows.Storage.FileAccessMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def OpenTransactedWriteAsync(self: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    @winrt_mixinmethod
    def CopyOverloadDefaultNameAndOptions(self: win32more.Windows.Storage.IStorageFile, destinationFolder: win32more.Windows.Storage.IStorageFolder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def CopyOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageFile, destinationFolder: win32more.Windows.Storage.IStorageFolder, desiredNewName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def CopyOverload(self: win32more.Windows.Storage.IStorageFile, destinationFolder: win32more.Windows.Storage.IStorageFolder, desiredNewName: WinRT_String, option: win32more.Windows.Storage.NameCollisionOption) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def CopyAndReplaceAsync(self: win32more.Windows.Storage.IStorageFile, fileToReplace: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def MoveOverloadDefaultNameAndOptions(self: win32more.Windows.Storage.IStorageFile, destinationFolder: win32more.Windows.Storage.IStorageFolder) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def MoveOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageFile, destinationFolder: win32more.Windows.Storage.IStorageFolder, desiredNewName: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def MoveOverload(self: win32more.Windows.Storage.IStorageFile, destinationFolder: win32more.Windows.Storage.IStorageFolder, desiredNewName: WinRT_String, option: win32more.Windows.Storage.NameCollisionOption) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def MoveAndReplaceAsync(self: win32more.Windows.Storage.IStorageFile, fileToReplace: win32more.Windows.Storage.IStorageFile) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def RenameAsyncOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageItem, desiredName: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def RenameAsync(self: win32more.Windows.Storage.IStorageItem, desiredName: WinRT_String, option: win32more.Windows.Storage.NameCollisionOption) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def DeleteAsyncOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def DeleteAsync(self: win32more.Windows.Storage.IStorageItem, option: win32more.Windows.Storage.StorageDeleteOption) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetBasicPropertiesAsync(self: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.FileProperties.BasicProperties]: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Storage.IStorageItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Path(self: win32more.Windows.Storage.IStorageItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Storage.FileAttributes: ...
    @winrt_mixinmethod
    def get_DateCreated(self: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def IsOfType(self: win32more.Windows.Storage.IStorageItem, type: win32more.Windows.Storage.StorageItemTypes) -> Boolean: ...
    @winrt_mixinmethod
    def OpenReadAsync(self: win32more.Windows.Storage.Streams.IRandomAccessStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStreamWithContentType]: ...
    @winrt_mixinmethod
    def OpenSequentialReadAsync(self: win32more.Windows.Storage.Streams.IInputStreamReference) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IInputStream]: ...
    @winrt_mixinmethod
    def GetThumbnailAsyncOverloadDefaultSizeDefaultOptions(self: win32more.Windows.Storage.IStorageItemProperties, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.FileProperties.StorageItemThumbnail]: ...
    @winrt_mixinmethod
    def GetThumbnailAsyncOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageItemProperties, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedSize: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.FileProperties.StorageItemThumbnail]: ...
    @winrt_mixinmethod
    def GetThumbnailAsync(self: win32more.Windows.Storage.IStorageItemProperties, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedSize: UInt32, options: win32more.Windows.Storage.FileProperties.ThumbnailOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.FileProperties.StorageItemThumbnail]: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Storage.IStorageItemProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayType(self: win32more.Windows.Storage.IStorageItemProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FolderRelativeId(self: win32more.Windows.Storage.IStorageItemProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Storage.IStorageItemProperties) -> win32more.Windows.Storage.FileProperties.StorageItemContentProperties: ...
    @winrt_mixinmethod
    def GetParentAsync(self: win32more.Windows.Storage.IStorageItem2) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def IsEqual(self: win32more.Windows.Storage.IStorageItem2, item: win32more.Windows.Storage.IStorageItem) -> Boolean: ...
    @winrt_mixinmethod
    def get_Provider(self: win32more.Windows.Storage.IStorageItemPropertiesWithProvider) -> win32more.Windows.Storage.StorageProvider: ...
    @winrt_mixinmethod
    def get_IsAvailable(self: win32more.Windows.Storage.IStorageFilePropertiesWithAvailability) -> Boolean: ...
    @winrt_mixinmethod
    def OpenWithOptionsAsync(self: win32more.Windows.Storage.IStorageFile2, accessMode: win32more.Windows.Storage.FileAccessMode, options: win32more.Windows.Storage.StorageOpenOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Streams.IRandomAccessStream]: ...
    @winrt_mixinmethod
    def OpenTransactedWriteWithOptionsAsync(self: win32more.Windows.Storage.IStorageFile2, options: win32more.Windows.Storage.StorageOpenOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageStreamTransaction]: ...
    Attributes = property(get_Attributes, None)
    BasicProperties = property(get_BasicProperties, None)
    ContentType = property(get_ContentType, None)
    DateCreated = property(get_DateCreated, None)
    DisplayName = property(get_DisplayName, None)
    DisplayType = property(get_DisplayType, None)
    DocumentProperties = property(get_DocumentProperties, None)
    FileType = property(get_FileType, None)
    FolderRelativeId = property(get_FolderRelativeId, None)
    ImageProperties = property(get_ImageProperties, None)
    IsAvailable = property(get_IsAvailable, None)
    MusicProperties = property(get_MusicProperties, None)
    Name = property(get_Name, None)
    Path = property(get_Path, None)
    Properties = property(get_Properties, None)
    Provider = property(get_Provider, None)
    Thumbnail = property(get_Thumbnail, None)
    VideoProperties = property(get_VideoProperties, None)
    ThumbnailUpdated = event()
    PropertiesUpdated = event()
class FileInformationFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.BulkAccess.IFileInformationFactory
    _classid_ = 'Windows.Storage.BulkAccess.FileInformationFactory'
    def __init__(self, *args, **kwargs):
        if kwargs:
            super().__init__(**kwargs)
        elif len(args) == 2:
            super().__init__(move=win32more.Windows.Storage.BulkAccess.FileInformationFactory.CreateWithMode(*args))
        elif len(args) == 3:
            super().__init__(move=win32more.Windows.Storage.BulkAccess.FileInformationFactory.CreateWithModeAndSize(*args))
        elif len(args) == 4:
            super().__init__(move=win32more.Windows.Storage.BulkAccess.FileInformationFactory.CreateWithModeAndSizeAndOptions(*args))
        elif len(args) == 5:
            super().__init__(move=win32more.Windows.Storage.BulkAccess.FileInformationFactory.CreateWithModeAndSizeAndOptionsAndFlags(*args))
        else:
            raise ValueError('no matched constructor')
    @winrt_factorymethod
    def CreateWithMode(cls: win32more.Windows.Storage.BulkAccess.IFileInformationFactoryFactory, queryResult: win32more.Windows.Storage.Search.IStorageQueryResultBase, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode) -> win32more.Windows.Storage.BulkAccess.FileInformationFactory: ...
    @winrt_factorymethod
    def CreateWithModeAndSize(cls: win32more.Windows.Storage.BulkAccess.IFileInformationFactoryFactory, queryResult: win32more.Windows.Storage.Search.IStorageQueryResultBase, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedThumbnailSize: UInt32) -> win32more.Windows.Storage.BulkAccess.FileInformationFactory: ...
    @winrt_factorymethod
    def CreateWithModeAndSizeAndOptions(cls: win32more.Windows.Storage.BulkAccess.IFileInformationFactoryFactory, queryResult: win32more.Windows.Storage.Search.IStorageQueryResultBase, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedThumbnailSize: UInt32, thumbnailOptions: win32more.Windows.Storage.FileProperties.ThumbnailOptions) -> win32more.Windows.Storage.BulkAccess.FileInformationFactory: ...
    @winrt_factorymethod
    def CreateWithModeAndSizeAndOptionsAndFlags(cls: win32more.Windows.Storage.BulkAccess.IFileInformationFactoryFactory, queryResult: win32more.Windows.Storage.Search.IStorageQueryResultBase, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedThumbnailSize: UInt32, thumbnailOptions: win32more.Windows.Storage.FileProperties.ThumbnailOptions, delayLoad: Boolean) -> win32more.Windows.Storage.BulkAccess.FileInformationFactory: ...
    @winrt_mixinmethod
    def GetItemsAsync(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.IStorageItemInformation]]: ...
    @winrt_mixinmethod
    def GetItemsAsyncDefaultStartAndCount(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.IStorageItemInformation]]: ...
    @winrt_mixinmethod
    def GetFilesAsync(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.FileInformation]]: ...
    @winrt_mixinmethod
    def GetFilesAsyncDefaultStartAndCount(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.FileInformation]]: ...
    @winrt_mixinmethod
    def GetFoldersAsync(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.FolderInformation]]: ...
    @winrt_mixinmethod
    def GetFoldersAsyncDefaultStartAndCount(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.FolderInformation]]: ...
    @winrt_mixinmethod
    def GetVirtualizedItemsVector(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def GetVirtualizedFilesVector(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_mixinmethod
    def GetVirtualizedFoldersVector(self: win32more.Windows.Storage.BulkAccess.IFileInformationFactory) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
class FolderInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.Storage.BulkAccess.IStorageItemInformation
    _classid_ = 'Windows.Storage.BulkAccess.FolderInformation'
    @winrt_mixinmethod
    def get_MusicProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.MusicProperties: ...
    @winrt_mixinmethod
    def get_VideoProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.VideoProperties: ...
    @winrt_mixinmethod
    def get_ImageProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.ImageProperties: ...
    @winrt_mixinmethod
    def get_DocumentProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.DocumentProperties: ...
    @winrt_mixinmethod
    def get_BasicProperties(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.BasicProperties: ...
    @winrt_mixinmethod
    def get_Thumbnail(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation) -> win32more.Windows.Storage.FileProperties.StorageItemThumbnail: ...
    @winrt_mixinmethod
    def add_ThumbnailUpdated(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation, changedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.BulkAccess.IStorageItemInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_ThumbnailUpdated(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def add_PropertiesUpdated(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation, changedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.BulkAccess.IStorageItemInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_mixinmethod
    def remove_PropertiesUpdated(self: win32more.Windows.Storage.BulkAccess.IStorageItemInformation, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_mixinmethod
    def CreateFileAsyncOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageFolder, desiredName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def CreateFileAsync(self: win32more.Windows.Storage.IStorageFolder, desiredName: WinRT_String, options: win32more.Windows.Storage.CreationCollisionOption) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def CreateFolderAsyncOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageFolder, desiredName: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def CreateFolderAsync(self: win32more.Windows.Storage.IStorageFolder, desiredName: WinRT_String, options: win32more.Windows.Storage.CreationCollisionOption) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def GetFileAsync(self: win32more.Windows.Storage.IStorageFolder, name: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFile]: ...
    @winrt_mixinmethod
    def GetFolderAsync(self: win32more.Windows.Storage.IStorageFolder, name: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def GetItemAsync(self: win32more.Windows.Storage.IStorageFolder, name: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.IStorageItem]: ...
    @winrt_mixinmethod
    def GetFilesAsyncOverloadDefaultOptionsStartAndCount(self: win32more.Windows.Storage.IStorageFolder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]]: ...
    @winrt_mixinmethod
    def GetFoldersAsyncOverloadDefaultOptionsStartAndCount(self: win32more.Windows.Storage.IStorageFolder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFolder]]: ...
    @winrt_mixinmethod
    def GetItemsAsyncOverloadDefaultStartAndCount(self: win32more.Windows.Storage.IStorageFolder) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.IStorageItem]]: ...
    @winrt_mixinmethod
    def RenameAsyncOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageItem, desiredName: WinRT_String) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def RenameAsync(self: win32more.Windows.Storage.IStorageItem, desiredName: WinRT_String, option: win32more.Windows.Storage.NameCollisionOption) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def DeleteAsyncOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def DeleteAsync(self: win32more.Windows.Storage.IStorageItem, option: win32more.Windows.Storage.StorageDeleteOption) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_mixinmethod
    def GetBasicPropertiesAsync(self: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.FileProperties.BasicProperties]: ...
    @winrt_mixinmethod
    def get_Name(self: win32more.Windows.Storage.IStorageItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Path(self: win32more.Windows.Storage.IStorageItem) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Attributes(self: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Storage.FileAttributes: ...
    @winrt_mixinmethod
    def get_DateCreated(self: win32more.Windows.Storage.IStorageItem) -> win32more.Windows.Foundation.DateTime: ...
    @winrt_mixinmethod
    def IsOfType(self: win32more.Windows.Storage.IStorageItem, type: win32more.Windows.Storage.StorageItemTypes) -> Boolean: ...
    @winrt_mixinmethod
    def GetThumbnailAsyncOverloadDefaultSizeDefaultOptions(self: win32more.Windows.Storage.IStorageItemProperties, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.FileProperties.StorageItemThumbnail]: ...
    @winrt_mixinmethod
    def GetThumbnailAsyncOverloadDefaultOptions(self: win32more.Windows.Storage.IStorageItemProperties, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedSize: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.FileProperties.StorageItemThumbnail]: ...
    @winrt_mixinmethod
    def GetThumbnailAsync(self: win32more.Windows.Storage.IStorageItemProperties, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedSize: UInt32, options: win32more.Windows.Storage.FileProperties.ThumbnailOptions) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.FileProperties.StorageItemThumbnail]: ...
    @winrt_mixinmethod
    def get_DisplayName(self: win32more.Windows.Storage.IStorageItemProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_DisplayType(self: win32more.Windows.Storage.IStorageItemProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_FolderRelativeId(self: win32more.Windows.Storage.IStorageItemProperties) -> WinRT_String: ...
    @winrt_mixinmethod
    def get_Properties(self: win32more.Windows.Storage.IStorageItemProperties) -> win32more.Windows.Storage.FileProperties.StorageItemContentProperties: ...
    @winrt_mixinmethod
    def GetIndexedStateAsync(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.Search.IndexedState]: ...
    @winrt_mixinmethod
    def CreateFileQueryOverloadDefault(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations) -> win32more.Windows.Storage.Search.StorageFileQueryResult: ...
    @winrt_mixinmethod
    def CreateFileQuery(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, query: win32more.Windows.Storage.Search.CommonFileQuery) -> win32more.Windows.Storage.Search.StorageFileQueryResult: ...
    @winrt_mixinmethod
    def CreateFileQueryWithOptions(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, queryOptions: win32more.Windows.Storage.Search.QueryOptions) -> win32more.Windows.Storage.Search.StorageFileQueryResult: ...
    @winrt_mixinmethod
    def CreateFolderQueryOverloadDefault(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations) -> win32more.Windows.Storage.Search.StorageFolderQueryResult: ...
    @winrt_mixinmethod
    def CreateFolderQuery(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, query: win32more.Windows.Storage.Search.CommonFolderQuery) -> win32more.Windows.Storage.Search.StorageFolderQueryResult: ...
    @winrt_mixinmethod
    def CreateFolderQueryWithOptions(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, queryOptions: win32more.Windows.Storage.Search.QueryOptions) -> win32more.Windows.Storage.Search.StorageFolderQueryResult: ...
    @winrt_mixinmethod
    def CreateItemQuery(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations) -> win32more.Windows.Storage.Search.StorageItemQueryResult: ...
    @winrt_mixinmethod
    def CreateItemQueryWithOptions(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, queryOptions: win32more.Windows.Storage.Search.QueryOptions) -> win32more.Windows.Storage.Search.StorageItemQueryResult: ...
    @winrt_mixinmethod
    def GetFilesAsync(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, query: win32more.Windows.Storage.Search.CommonFileQuery, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]]: ...
    @winrt_mixinmethod
    def GetFilesAsyncOverloadDefaultStartAndCount(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, query: win32more.Windows.Storage.Search.CommonFileQuery) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFile]]: ...
    @winrt_mixinmethod
    def GetFoldersAsync(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, query: win32more.Windows.Storage.Search.CommonFolderQuery, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFolder]]: ...
    @winrt_mixinmethod
    def GetFoldersAsyncOverloadDefaultStartAndCount(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, query: win32more.Windows.Storage.Search.CommonFolderQuery) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.StorageFolder]]: ...
    @winrt_mixinmethod
    def GetItemsAsync(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.IStorageItem]]: ...
    @winrt_mixinmethod
    def AreQueryOptionsSupported(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, queryOptions: win32more.Windows.Storage.Search.QueryOptions) -> Boolean: ...
    @winrt_mixinmethod
    def IsCommonFolderQuerySupported(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, query: win32more.Windows.Storage.Search.CommonFolderQuery) -> Boolean: ...
    @winrt_mixinmethod
    def IsCommonFileQuerySupported(self: win32more.Windows.Storage.Search.IStorageFolderQueryOperations, query: win32more.Windows.Storage.Search.CommonFileQuery) -> Boolean: ...
    @winrt_mixinmethod
    def GetParentAsync(self: win32more.Windows.Storage.IStorageItem2) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.StorageFolder]: ...
    @winrt_mixinmethod
    def IsEqual(self: win32more.Windows.Storage.IStorageItem2, item: win32more.Windows.Storage.IStorageItem) -> Boolean: ...
    @winrt_mixinmethod
    def TryGetItemAsync(self: win32more.Windows.Storage.IStorageFolder2, name: WinRT_String) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Storage.IStorageItem]: ...
    @winrt_mixinmethod
    def get_Provider(self: win32more.Windows.Storage.IStorageItemPropertiesWithProvider) -> win32more.Windows.Storage.StorageProvider: ...
    Attributes = property(get_Attributes, None)
    BasicProperties = property(get_BasicProperties, None)
    DateCreated = property(get_DateCreated, None)
    DisplayName = property(get_DisplayName, None)
    DisplayType = property(get_DisplayType, None)
    DocumentProperties = property(get_DocumentProperties, None)
    FolderRelativeId = property(get_FolderRelativeId, None)
    ImageProperties = property(get_ImageProperties, None)
    MusicProperties = property(get_MusicProperties, None)
    Name = property(get_Name, None)
    Path = property(get_Path, None)
    Properties = property(get_Properties, None)
    Provider = property(get_Provider, None)
    Thumbnail = property(get_Thumbnail, None)
    VideoProperties = property(get_VideoProperties, None)
    ThumbnailUpdated = event()
    PropertiesUpdated = event()
class IFileInformationFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.BulkAccess.IFileInformationFactory'
    _iid_ = Guid('{401d88be-960f-4d6d-a7d0-1a3861e76c83}')
    @winrt_commethod(6)
    def GetItemsAsync(self, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.IStorageItemInformation]]: ...
    @winrt_commethod(7)
    def GetItemsAsyncDefaultStartAndCount(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.IStorageItemInformation]]: ...
    @winrt_commethod(8)
    def GetFilesAsync(self, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.FileInformation]]: ...
    @winrt_commethod(9)
    def GetFilesAsyncDefaultStartAndCount(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.FileInformation]]: ...
    @winrt_commethod(10)
    def GetFoldersAsync(self, startIndex: UInt32, maxItemsToRetrieve: UInt32) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.FolderInformation]]: ...
    @winrt_commethod(11)
    def GetFoldersAsyncDefaultStartAndCount(self) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.Foundation.Collections.IVectorView[win32more.Windows.Storage.BulkAccess.FolderInformation]]: ...
    @winrt_commethod(12)
    def GetVirtualizedItemsVector(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(13)
    def GetVirtualizedFilesVector(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
    @winrt_commethod(14)
    def GetVirtualizedFoldersVector(self) -> win32more.Windows.Win32.System.WinRT.IInspectable: ...
class IFileInformationFactoryFactory(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.BulkAccess.IFileInformationFactoryFactory'
    _iid_ = Guid('{84ea0e7d-e4a2-4f00-8afa-af5e0f826bd5}')
    @winrt_commethod(6)
    def CreateWithMode(self, queryResult: win32more.Windows.Storage.Search.IStorageQueryResultBase, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode) -> win32more.Windows.Storage.BulkAccess.FileInformationFactory: ...
    @winrt_commethod(7)
    def CreateWithModeAndSize(self, queryResult: win32more.Windows.Storage.Search.IStorageQueryResultBase, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedThumbnailSize: UInt32) -> win32more.Windows.Storage.BulkAccess.FileInformationFactory: ...
    @winrt_commethod(8)
    def CreateWithModeAndSizeAndOptions(self, queryResult: win32more.Windows.Storage.Search.IStorageQueryResultBase, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedThumbnailSize: UInt32, thumbnailOptions: win32more.Windows.Storage.FileProperties.ThumbnailOptions) -> win32more.Windows.Storage.BulkAccess.FileInformationFactory: ...
    @winrt_commethod(9)
    def CreateWithModeAndSizeAndOptionsAndFlags(self, queryResult: win32more.Windows.Storage.Search.IStorageQueryResultBase, mode: win32more.Windows.Storage.FileProperties.ThumbnailMode, requestedThumbnailSize: UInt32, thumbnailOptions: win32more.Windows.Storage.FileProperties.ThumbnailOptions, delayLoad: Boolean) -> win32more.Windows.Storage.BulkAccess.FileInformationFactory: ...
class IStorageItemInformation(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.Storage.BulkAccess.IStorageItemInformation'
    _iid_ = Guid('{87a5cb8b-8972-4f40-8de0-d86fb179d8fa}')
    @winrt_commethod(6)
    def get_MusicProperties(self) -> win32more.Windows.Storage.FileProperties.MusicProperties: ...
    @winrt_commethod(7)
    def get_VideoProperties(self) -> win32more.Windows.Storage.FileProperties.VideoProperties: ...
    @winrt_commethod(8)
    def get_ImageProperties(self) -> win32more.Windows.Storage.FileProperties.ImageProperties: ...
    @winrt_commethod(9)
    def get_DocumentProperties(self) -> win32more.Windows.Storage.FileProperties.DocumentProperties: ...
    @winrt_commethod(10)
    def get_BasicProperties(self) -> win32more.Windows.Storage.FileProperties.BasicProperties: ...
    @winrt_commethod(11)
    def get_Thumbnail(self) -> win32more.Windows.Storage.FileProperties.StorageItemThumbnail: ...
    @winrt_commethod(12)
    def add_ThumbnailUpdated(self, changedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.BulkAccess.IStorageItemInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(13)
    def remove_ThumbnailUpdated(self, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    @winrt_commethod(14)
    def add_PropertiesUpdated(self, changedHandler: win32more.Windows.Foundation.TypedEventHandler[win32more.Windows.Storage.BulkAccess.IStorageItemInformation, win32more.Windows.Win32.System.WinRT.IInspectable]) -> win32more.Windows.Foundation.EventRegistrationToken: ...
    @winrt_commethod(15)
    def remove_PropertiesUpdated(self, eventCookie: win32more.Windows.Foundation.EventRegistrationToken) -> Void: ...
    BasicProperties = property(get_BasicProperties, None)
    DocumentProperties = property(get_DocumentProperties, None)
    ImageProperties = property(get_ImageProperties, None)
    MusicProperties = property(get_MusicProperties, None)
    Thumbnail = property(get_Thumbnail, None)
    VideoProperties = property(get_VideoProperties, None)
    ThumbnailUpdated = event()
    PropertiesUpdated = event()


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
from win32more._winrt import AwaitableProtocol, ContextManagerProtocol, FillArray, Generic, IterableProtocol, K, MappingProtocol, MulticastDelegate, PassArray, ReceiveArray, SequenceProtocol, T, TProgress, TResult, TSender, Tuple, V, WinRT_String, event, winrt_activatemethod, winrt_classmethod, winrt_commethod, winrt_factorymethod, winrt_mixinmethod, winrt_overload
import win32more.Windows.ApplicationModel.Store.LicenseManagement
import win32more.Windows.Foundation
import win32more.Windows.Foundation.Collections
import win32more.Windows.Storage.Streams
import win32more.Windows.Win32.System.WinRT
class ILicenseManagerStatics(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.LicenseManagement.ILicenseManagerStatics'
    _iid_ = Guid('{b5ac3ae0-da47-4f20-9a23-09182c9476ff}')
    @winrt_commethod(6)
    def AddLicenseAsync(self, license: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_commethod(7)
    def GetSatisfactionInfosAsync(self, contentIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], keyIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Store.LicenseManagement.LicenseSatisfactionResult]: ...
class ILicenseManagerStatics2(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.LicenseManagement.ILicenseManagerStatics2'
    _iid_ = Guid('{ab2ec47b-1f79-4480-b87e-2c499e601ba3}')
    @winrt_commethod(6)
    def RefreshLicensesAsync(self, refreshOption: win32more.Windows.ApplicationModel.Store.LicenseManagement.LicenseRefreshOption) -> win32more.Windows.Foundation.IAsyncAction: ...
class ILicenseSatisfactionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo'
    _iid_ = Guid('{3ccbb08f-db31-48d5-8384-fa17c81474e2}')
    @winrt_commethod(6)
    def get_SatisfiedByDevice(self) -> Boolean: ...
    @winrt_commethod(7)
    def get_SatisfiedByOpenLicense(self) -> Boolean: ...
    @winrt_commethod(8)
    def get_SatisfiedByTrial(self) -> Boolean: ...
    @winrt_commethod(9)
    def get_SatisfiedByPass(self) -> Boolean: ...
    @winrt_commethod(10)
    def get_SatisfiedByInstallMedia(self) -> Boolean: ...
    @winrt_commethod(11)
    def get_SatisfiedBySignedInUser(self) -> Boolean: ...
    @winrt_commethod(12)
    def get_IsSatisfied(self) -> Boolean: ...
    IsSatisfied = property(get_IsSatisfied, None)
    SatisfiedByDevice = property(get_SatisfiedByDevice, None)
    SatisfiedByInstallMedia = property(get_SatisfiedByInstallMedia, None)
    SatisfiedByOpenLicense = property(get_SatisfiedByOpenLicense, None)
    SatisfiedByPass = property(get_SatisfiedByPass, None)
    SatisfiedBySignedInUser = property(get_SatisfiedBySignedInUser, None)
    SatisfiedByTrial = property(get_SatisfiedByTrial, None)
class ILicenseSatisfactionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionResult'
    _iid_ = Guid('{3c674f73-3c87-4ee1-8201-f428359bd3af}')
    @winrt_commethod(6)
    def get_LicenseSatisfactionInfos(self) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Store.LicenseManagement.LicenseSatisfactionInfo]: ...
    @winrt_commethod(7)
    def get_ExtendedError(self) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    LicenseSatisfactionInfos = property(get_LicenseSatisfactionInfos, None)
class LicenseManager(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    _classid_ = 'Windows.ApplicationModel.Store.LicenseManagement.LicenseManager'
    @winrt_classmethod
    def RefreshLicensesAsync(cls: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseManagerStatics2, refreshOption: win32more.Windows.ApplicationModel.Store.LicenseManagement.LicenseRefreshOption) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def AddLicenseAsync(cls: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseManagerStatics, license: win32more.Windows.Storage.Streams.IBuffer) -> win32more.Windows.Foundation.IAsyncAction: ...
    @winrt_classmethod
    def GetSatisfactionInfosAsync(cls: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseManagerStatics, contentIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String], keyIds: win32more.Windows.Foundation.Collections.IIterable[WinRT_String]) -> win32more.Windows.Foundation.IAsyncOperation[win32more.Windows.ApplicationModel.Store.LicenseManagement.LicenseSatisfactionResult]: ...
class LicenseRefreshOption(Enum, Int32):
    RunningLicenses = 0
    AllLicenses = 1
class LicenseSatisfactionInfo(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo
    _classid_ = 'Windows.ApplicationModel.Store.LicenseManagement.LicenseSatisfactionInfo'
    @winrt_mixinmethod
    def get_SatisfiedByDevice(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_SatisfiedByOpenLicense(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_SatisfiedByTrial(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_SatisfiedByPass(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_SatisfiedByInstallMedia(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_SatisfiedBySignedInUser(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo) -> Boolean: ...
    @winrt_mixinmethod
    def get_IsSatisfied(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionInfo) -> Boolean: ...
    IsSatisfied = property(get_IsSatisfied, None)
    SatisfiedByDevice = property(get_SatisfiedByDevice, None)
    SatisfiedByInstallMedia = property(get_SatisfiedByInstallMedia, None)
    SatisfiedByOpenLicense = property(get_SatisfiedByOpenLicense, None)
    SatisfiedByPass = property(get_SatisfiedByPass, None)
    SatisfiedBySignedInUser = property(get_SatisfiedBySignedInUser, None)
    SatisfiedByTrial = property(get_SatisfiedByTrial, None)
class LicenseSatisfactionResult(ComPtr):
    extends: win32more.Windows.Win32.System.WinRT.IInspectable
    default_interface: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionResult
    _classid_ = 'Windows.ApplicationModel.Store.LicenseManagement.LicenseSatisfactionResult'
    @winrt_mixinmethod
    def get_LicenseSatisfactionInfos(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionResult) -> win32more.Windows.Foundation.Collections.IMapView[WinRT_String, win32more.Windows.ApplicationModel.Store.LicenseManagement.LicenseSatisfactionInfo]: ...
    @winrt_mixinmethod
    def get_ExtendedError(self: win32more.Windows.ApplicationModel.Store.LicenseManagement.ILicenseSatisfactionResult) -> win32more.Windows.Foundation.HResult: ...
    ExtendedError = property(get_ExtendedError, None)
    LicenseSatisfactionInfos = property(get_LicenseSatisfactionInfos, None)


make_ready(__name__)



from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Diagnostics.Debug
import win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting
import win32more.Windows.Win32.System.Memory
PSS_PERF_RESOLUTION: UInt32 = 1000000
@winfunctype('KERNEL32.dll')
def PssCaptureSnapshot(ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, CaptureFlags: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS, ThreadContextFlags: UInt32, SnapshotHandle: POINTER(win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSS)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssFreeSnapshot(ProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, SnapshotHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSS) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssQuerySnapshot(SnapshotHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSS, InformationClass: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS, Buffer: VoidPtr, BufferLength: UInt32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssWalkSnapshot(SnapshotHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSS, InformationClass: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_WALK_INFORMATION_CLASS, WalkMarkerHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSSWALK, Buffer: VoidPtr, BufferLength: UInt32) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssDuplicateSnapshot(SourceProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, SnapshotHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSS, TargetProcessHandle: win32more.Windows.Win32.Foundation.HANDLE, TargetSnapshotHandle: POINTER(win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSS), Flags: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_DUPLICATE_FLAGS) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssWalkMarkerCreate(Allocator: POINTER(win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_ALLOCATOR), WalkMarkerHandle: POINTER(win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSSWALK)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssWalkMarkerFree(WalkMarkerHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSSWALK) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssWalkMarkerGetPosition(WalkMarkerHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSSWALK, Position: POINTER(UIntPtr)) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssWalkMarkerSetPosition(WalkMarkerHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSSWALK, Position: UIntPtr) -> UInt32: ...
@winfunctype('KERNEL32.dll')
def PssWalkMarkerSeekToBeginning(WalkMarkerHandle: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.HPSSWALK) -> UInt32: ...
HPSS = VoidPtr
HPSSWALK = VoidPtr
class PSS_ALLOCATOR(Structure):
    Context: VoidPtr
    AllocRoutine: IntPtr
    FreeRoutine: IntPtr
class PSS_AUXILIARY_PAGES_INFORMATION(Structure):
    AuxPagesCaptured: UInt32
class PSS_AUXILIARY_PAGE_ENTRY(Structure):
    Address: VoidPtr
    BasicInformation: win32more.Windows.Win32.System.Memory.MEMORY_BASIC_INFORMATION
    CaptureTime: win32more.Windows.Win32.Foundation.FILETIME
    PageContents: VoidPtr
    PageSize: UInt32
PSS_CAPTURE_FLAGS = UInt32
PSS_CAPTURE_NONE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 0
PSS_CAPTURE_VA_CLONE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 1
PSS_CAPTURE_RESERVED_00000002: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 2
PSS_CAPTURE_HANDLES: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 4
PSS_CAPTURE_HANDLE_NAME_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 8
PSS_CAPTURE_HANDLE_BASIC_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 16
PSS_CAPTURE_HANDLE_TYPE_SPECIFIC_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 32
PSS_CAPTURE_HANDLE_TRACE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 64
PSS_CAPTURE_THREADS: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 128
PSS_CAPTURE_THREAD_CONTEXT: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 256
PSS_CAPTURE_THREAD_CONTEXT_EXTENDED: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 512
PSS_CAPTURE_RESERVED_00000400: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 1024
PSS_CAPTURE_VA_SPACE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 2048
PSS_CAPTURE_VA_SPACE_SECTION_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 4096
PSS_CAPTURE_IPT_TRACE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 8192
PSS_CAPTURE_RESERVED_00004000: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 16384
PSS_CREATE_BREAKAWAY_OPTIONAL: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 67108864
PSS_CREATE_BREAKAWAY: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 134217728
PSS_CREATE_FORCE_BREAKAWAY: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 268435456
PSS_CREATE_USE_VM_ALLOCATIONS: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 536870912
PSS_CREATE_MEASURE_PERFORMANCE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 1073741824
PSS_CREATE_RELEASE_SECTION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_CAPTURE_FLAGS = 2147483648
PSS_DUPLICATE_FLAGS = Int32
PSS_DUPLICATE_NONE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_DUPLICATE_FLAGS = 0
PSS_DUPLICATE_CLOSE_SOURCE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_DUPLICATE_FLAGS = 1
class PSS_HANDLE_ENTRY(Structure):
    Handle: win32more.Windows.Win32.Foundation.HANDLE
    Flags: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_HANDLE_FLAGS
    ObjectType: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_OBJECT_TYPE
    CaptureTime: win32more.Windows.Win32.Foundation.FILETIME
    Attributes: UInt32
    GrantedAccess: UInt32
    HandleCount: UInt32
    PointerCount: UInt32
    PagedPoolCharge: UInt32
    NonPagedPoolCharge: UInt32
    CreationTime: win32more.Windows.Win32.Foundation.FILETIME
    TypeNameLength: UInt16
    TypeName: win32more.Windows.Win32.Foundation.PWSTR
    ObjectNameLength: UInt16
    ObjectName: win32more.Windows.Win32.Foundation.PWSTR
    TypeSpecificInformation: _TypeSpecificInformation_e__Union
    class _TypeSpecificInformation_e__Union(Union):
        Process: _Process_e__Struct
        Thread: _Thread_e__Struct
        Mutant: _Mutant_e__Struct
        Event: _Event_e__Struct
        Section: _Section_e__Struct
        Semaphore: _Semaphore_e__Struct
        class _Process_e__Struct(Structure):
            ExitStatus: UInt32
            PebBaseAddress: VoidPtr
            AffinityMask: UIntPtr
            BasePriority: Int32
            ProcessId: UInt32
            ParentProcessId: UInt32
            Flags: UInt32
        class _Thread_e__Struct(Structure):
            ExitStatus: UInt32
            TebBaseAddress: VoidPtr
            ProcessId: UInt32
            ThreadId: UInt32
            AffinityMask: UIntPtr
            Priority: Int32
            BasePriority: Int32
            Win32StartAddress: VoidPtr
        class _Mutant_e__Struct(Structure):
            CurrentCount: Int32
            Abandoned: win32more.Windows.Win32.Foundation.BOOL
            OwnerProcessId: UInt32
            OwnerThreadId: UInt32
        class _Event_e__Struct(Structure):
            ManualReset: win32more.Windows.Win32.Foundation.BOOL
            Signaled: win32more.Windows.Win32.Foundation.BOOL
        class _Section_e__Struct(Structure):
            BaseAddress: VoidPtr
            AllocationAttributes: UInt32
            MaximumSize: Int64
        class _Semaphore_e__Struct(Structure):
            CurrentCount: Int32
            MaximumCount: Int32
PSS_HANDLE_FLAGS = Int32
PSS_HANDLE_NONE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_HANDLE_FLAGS = 0
PSS_HANDLE_HAVE_TYPE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_HANDLE_FLAGS = 1
PSS_HANDLE_HAVE_NAME: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_HANDLE_FLAGS = 2
PSS_HANDLE_HAVE_BASIC_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_HANDLE_FLAGS = 4
PSS_HANDLE_HAVE_TYPE_SPECIFIC_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_HANDLE_FLAGS = 8
class PSS_HANDLE_INFORMATION(Structure):
    HandlesCaptured: UInt32
class PSS_HANDLE_TRACE_INFORMATION(Structure):
    SectionHandle: win32more.Windows.Win32.Foundation.HANDLE
    Size: UInt32
PSS_OBJECT_TYPE = Int32
PSS_OBJECT_TYPE_UNKNOWN: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_OBJECT_TYPE = 0
PSS_OBJECT_TYPE_PROCESS: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_OBJECT_TYPE = 1
PSS_OBJECT_TYPE_THREAD: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_OBJECT_TYPE = 2
PSS_OBJECT_TYPE_MUTANT: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_OBJECT_TYPE = 3
PSS_OBJECT_TYPE_EVENT: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_OBJECT_TYPE = 4
PSS_OBJECT_TYPE_SECTION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_OBJECT_TYPE = 5
PSS_OBJECT_TYPE_SEMAPHORE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_OBJECT_TYPE = 6
class PSS_PERFORMANCE_COUNTERS(Structure):
    TotalCycleCount: UInt64
    TotalWallClockPeriod: UInt64
    VaCloneCycleCount: UInt64
    VaCloneWallClockPeriod: UInt64
    VaSpaceCycleCount: UInt64
    VaSpaceWallClockPeriod: UInt64
    AuxPagesCycleCount: UInt64
    AuxPagesWallClockPeriod: UInt64
    HandlesCycleCount: UInt64
    HandlesWallClockPeriod: UInt64
    ThreadsCycleCount: UInt64
    ThreadsWallClockPeriod: UInt64
PSS_PROCESS_FLAGS = Int32
PSS_PROCESS_FLAGS_NONE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_PROCESS_FLAGS = 0
PSS_PROCESS_FLAGS_PROTECTED: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_PROCESS_FLAGS = 1
PSS_PROCESS_FLAGS_WOW64: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_PROCESS_FLAGS = 2
PSS_PROCESS_FLAGS_RESERVED_03: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_PROCESS_FLAGS = 4
PSS_PROCESS_FLAGS_RESERVED_04: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_PROCESS_FLAGS = 8
PSS_PROCESS_FLAGS_FROZEN: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_PROCESS_FLAGS = 16
class PSS_PROCESS_INFORMATION(Structure):
    ExitStatus: UInt32
    PebBaseAddress: VoidPtr
    AffinityMask: UIntPtr
    BasePriority: Int32
    ProcessId: UInt32
    ParentProcessId: UInt32
    Flags: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_PROCESS_FLAGS
    CreateTime: win32more.Windows.Win32.Foundation.FILETIME
    ExitTime: win32more.Windows.Win32.Foundation.FILETIME
    KernelTime: win32more.Windows.Win32.Foundation.FILETIME
    UserTime: win32more.Windows.Win32.Foundation.FILETIME
    PriorityClass: UInt32
    PeakVirtualSize: UIntPtr
    VirtualSize: UIntPtr
    PageFaultCount: UInt32
    PeakWorkingSetSize: UIntPtr
    WorkingSetSize: UIntPtr
    QuotaPeakPagedPoolUsage: UIntPtr
    QuotaPagedPoolUsage: UIntPtr
    QuotaPeakNonPagedPoolUsage: UIntPtr
    QuotaNonPagedPoolUsage: UIntPtr
    PagefileUsage: UIntPtr
    PeakPagefileUsage: UIntPtr
    PrivateUsage: UIntPtr
    ExecuteFlags: UInt32
    ImageFileName: Char * 260
PSS_QUERY_INFORMATION_CLASS = Int32
PSS_QUERY_PROCESS_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS = 0
PSS_QUERY_VA_CLONE_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS = 1
PSS_QUERY_AUXILIARY_PAGES_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS = 2
PSS_QUERY_VA_SPACE_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS = 3
PSS_QUERY_HANDLE_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS = 4
PSS_QUERY_THREAD_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS = 5
PSS_QUERY_HANDLE_TRACE_INFORMATION: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS = 6
PSS_QUERY_PERFORMANCE_COUNTERS: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_QUERY_INFORMATION_CLASS = 7
class PSS_THREAD_ENTRY(Structure):
    ExitStatus: UInt32
    TebBaseAddress: VoidPtr
    ProcessId: UInt32
    ThreadId: UInt32
    AffinityMask: UIntPtr
    Priority: Int32
    BasePriority: Int32
    LastSyscallFirstArgument: VoidPtr
    LastSyscallNumber: UInt16
    CreateTime: win32more.Windows.Win32.Foundation.FILETIME
    ExitTime: win32more.Windows.Win32.Foundation.FILETIME
    KernelTime: win32more.Windows.Win32.Foundation.FILETIME
    UserTime: win32more.Windows.Win32.Foundation.FILETIME
    Win32StartAddress: VoidPtr
    CaptureTime: win32more.Windows.Win32.Foundation.FILETIME
    Flags: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_THREAD_FLAGS
    SuspendCount: UInt16
    SizeOfContextRecord: UInt16
    ContextRecord: POINTER(win32more.Windows.Win32.System.Diagnostics.Debug.CONTEXT)
PSS_THREAD_FLAGS = Int32
PSS_THREAD_FLAGS_NONE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_THREAD_FLAGS = 0
PSS_THREAD_FLAGS_TERMINATED: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_THREAD_FLAGS = 1
class PSS_THREAD_INFORMATION(Structure):
    ThreadsCaptured: UInt32
    ContextLength: UInt32
class PSS_VA_CLONE_INFORMATION(Structure):
    VaCloneHandle: win32more.Windows.Win32.Foundation.HANDLE
class PSS_VA_SPACE_ENTRY(Structure):
    BaseAddress: VoidPtr
    AllocationBase: VoidPtr
    AllocationProtect: UInt32
    RegionSize: UIntPtr
    State: UInt32
    Protect: UInt32
    Type: UInt32
    TimeDateStamp: UInt32
    SizeOfImage: UInt32
    ImageBase: VoidPtr
    CheckSum: UInt32
    MappedFileNameLength: UInt16
    MappedFileName: win32more.Windows.Win32.Foundation.PWSTR
class PSS_VA_SPACE_INFORMATION(Structure):
    RegionCount: UInt32
PSS_WALK_INFORMATION_CLASS = Int32
PSS_WALK_AUXILIARY_PAGES: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_WALK_INFORMATION_CLASS = 0
PSS_WALK_VA_SPACE: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_WALK_INFORMATION_CLASS = 1
PSS_WALK_HANDLES: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_WALK_INFORMATION_CLASS = 2
PSS_WALK_THREADS: win32more.Windows.Win32.System.Diagnostics.ProcessSnapshotting.PSS_WALK_INFORMATION_CLASS = 3


make_ready(__name__)
